@@ -16,5 +16,5 @@ G_CFG["profiles"] = {}
 gp_profile = None
 
 GC_FOLDER_PATH = Pathlib.Path(__file__).parent.resolve()
-GC_REPOS_PATH = OS.path.join(GC_FOLDER_PATH, GC_REPOS_NAME)
-GC_SRC_PATH = OS.path.join(GC_FOLDER_PATH, GC_SRC_NAME)
\ No newline at end of file
+GC_REPOS_PATH = OS.path.join(GC_FOLDER_PATH.parent, GC_REPOS_NAME)
+GC_SRC_PATH = OS.path.join(GC_FOLDER_PATH.parent, GC_SRC_NAME)
